@@ -36,22 +36,22 @@ def test_step_to_location():
 
     # ts[0] != t0
     ts = jnp.linspace(0.1, 2.0, 5)
-    with pytest.raises(ValueError):
+    with pytest.raises(RuntimeError):
         _test(ts)
 
     # ts[-1] != t1
     ts = jnp.linspace(0.0, 2.1, 5)
-    with pytest.raises(ValueError):
+    with pytest.raises(RuntimeError):
         _test(ts)
 
     # Not monotonic
     ts = jnp.array([0.0, 2.3, 2.0])
-    with pytest.raises(ValueError):
+    with pytest.raises(RuntimeError):
         _test(ts)
 
     # Reverse time
     ts = jnp.linspace(2.0, 0.0, 5)
-    with pytest.raises(ValueError):
+    with pytest.raises(RuntimeError):
         _test(ts)
     sol = _test(ts, flip=True)
     true_ys = jnp.array([1.0, 1.5, 2.25, 3.375, 5.0625])
